indexing
   description: "Door is a separation between two ROOMs.  It may be open or closed."
   date: "2004 March 28"
   version: "1.0"
   author: "Gunnar Gotshalks"

class DOOR
  inherit ROOM_COMPONENT

creation make

feature -- Initialization

make (door_id : STRING ; r1, r2 : ROOM) is
    -- Creation and initialization
  require
    door_has_id: door_id /= void
    rooms_exist: r1 /= void and r2 /= void
    rooms_different : r1 /= r2
  do
    room1 := r1 ; room2 := r2 ; id := door_id
  ensure
    door_set: room1 = r1 and room2 = r2
    id_set: id = door_id
  end

feature {ANY} -- Queries

room1, room2 : ROOM -- The ROOMs this DOOR connects

other_side_from (room: ROOM) : ROOM is
  require adjacent_room: room = room1 or room = room2
  do
    if room = room1 then Result := room2
	else Result := room1
	end
  end

is_open : BOOLEAN  -- True if door is open

feature {ANY} -- Commands

open is
  -- Opens the door
  require not is_open
  do
    is_open := True
  ensure is_open
  end

close is
  -- Close the door
  require is_open
  do
    is_open := False
  ensure not is_open
  end
  
describe is
  -- Describe door and its the state open/close
  do
    print(" " + id)
    if is_open then print(" open")
    else print(" closed")
    end
  end

end

