indexing
   description: "A Collection of ROOMs"
   date: "2004 March 28"
   version: "1.0"
   author: "Gunnar Gotshalks"

class MAZE
  creation make

feature -- Initialization

make is
  -- Creation and initialization
  do
    create rooms.make
  end

feature {ANY} -- Queries

room (id : STRING) : ROOM is
  -- Return the room with the given id or void if not in the maze.
  local r : LINKED_LIST[ROOM]  -- Clone of the rooms list
  do
    r := clone(rooms)
    from  r.start
    invariant  -- for k : 1..r.index-1 :: r.item.id /= id
    variant  r.count+1-r.index
    until r.after or r.item.id.is_equal(id)
    loop  r.forth
    end
  end

feature {ANY} -- Commands

add_room (new_room : ROOM) is
  -- Add a new ROOM to the MAZE
  require
    new_room_not_void: new_room /= Void
  do
    rooms.extend(new_room)
  end

describe is
  -- Print a terse description of each ROOM of the MAZE
  do
    print("%N----------------%NMaze made of:%N")
    from rooms.start
    until rooms.after
    loop
      print("  ")
      rooms.item.describe
      rooms.forth
    end
  end

feature {NONE} -- Implementation

rooms : LINKED_LIST[ROOM]

invariant
   rooms_not_void: rooms /= Void

end -- MAZE

